@@ -1,14 +1,26 @@
-# Spreadsheet::ParseExcel::FmtJapan
-#  by Kawai, Takanori (Hippo2000) 2001.2.2
-# This Program is ALPHA version.
-#==============================================================================
 package Spreadsheet::ParseExcel::FmtJapan;
+
+###############################################################################
+#
+# Spreadsheet::ParseExcel::FmtJapan - A class for Cell formats.
+#
+# Used in conjunction with Spreadsheet::ParseExcel.
+#
+# Copyright (c) 2009      John McNamara
+# Copyright (c) 2006-2008 Gabor Szabo
+# Copyright (c) 2000-2006 Kawai Takanori
+#
+# perltidy with standard settings.
+#
+# Documentation after __END__
+#
+
 use strict;
 use warnings;
 
 use Jcode;
 use base 'Spreadsheet::ParseExcel::FmtDefault';
-our $VERSION = '0.42';
+our $VERSION = '0.44';
 
 my %hFmtJapan = (
     0x00 => '@',
@@ -25,7 +37,8 @@ my %hFmtJapan = (
     0x0B => '0.00E+00',
     0x0C => '# ?/?',
     0x0D => '# ??/??',
-#    0x0E => 'm/d/yy',
+
+    #    0x0E => 'm/d/yy',
     0x0E => 'yyyy/m/d',
     0x0F => 'd-mmm-yy',
     0x10 => 'd-mmm',
@@ -34,15 +47,17 @@ my %hFmtJapan = (
     0x13 => 'h:mm:ss AM/PM',
     0x14 => 'h:mm',
     0x15 => 'h:mm:ss',
-#    0x16 => 'm/d/yy h:mm',
+
+    #    0x16 => 'm/d/yy h:mm',
     0x16 => 'yyyy/m/d h:mm',
 
-#0x17-0x24 -- Differs in Natinal
+    #0x17-0x24 -- Differs in Natinal
     0x1E => 'm/d/yy',
     0x1F => 'yyyy"ǯ"m""d""',
     0x20 => 'h""mm"ʬ"',
     0x21 => 'h""mm"ʬ"ss""',
-#0x17-0x24 -- Differs in Natinal
+
+    #0x17-0x24 -- Differs in Natinal
     0x25 => '(#,##0_);(#,##0)',
     0x26 => '(#,##0_);[RED](#,##0)',
     0x27 => '(#,##0.00);(#,##0.00)',
@@ -57,98 +72,145 @@ my %hFmtJapan = (
     0x30 => '##0.0E+0',
     0x31 => '@',
 
-    0x37 => 'yyyy"ǯ"m""',        
-    0x38 => 'm""d""',       
+    0x37 => 'yyyy"ǯ"m""',
+    0x38 => 'm""d""',
     0x39 => 'ge.m.d',
     0x3A => 'ggge"ǯ"m""d""',
 );
 my $_Code;
+
 #------------------------------------------------------------------------------
 # new (for Spreadsheet::ParseExcel::FmtJapan)
 #------------------------------------------------------------------------------
 sub new {
-    my($sPkg, %hKey) = @_;
-    my $oThis={ 
-        Code => $hKey{Code},
-    };
-    if($oThis->{Code}) {
-        foreach my $sKey (keys %hFmtJapan) {
-            $hFmtJapan{$sKey} = 
-                Jcode::convert($hFmtJapan{$sKey}, $oThis->{Code}, 'euc');
+    my ( $sPkg, %hKey ) = @_;
+    my $oThis = { Code => $hKey{Code}, };
+    if ( $oThis->{Code} ) {
+        foreach my $sKey ( keys %hFmtJapan ) {
+            $hFmtJapan{$sKey} =
+              Jcode::convert( $hFmtJapan{$sKey}, $oThis->{Code}, 'euc' );
         }
         $_Code = $oThis->{Code};
     }
     bless $oThis;
     return $oThis;
 }
+
 #------------------------------------------------------------------------------
 # TextFmt (for Spreadsheet::ParseExcel::FmtJapan)
 #------------------------------------------------------------------------------
 sub TextFmt {
-    my($oThis, $sTxt, $sCode) =@_;
+    my ( $oThis, $sTxt, $sCode ) = @_;
 
-    if($oThis->{Code}) {
-        if(! defined($sCode)) {
+    if ( $oThis->{Code} ) {
+        if ( !defined($sCode) ) {
             $sTxt =~ s/(.)/\x00$1/sg;
             $sCode = 'ucs2';
         }
-        elsif($sCode eq '_native_') {
+        elsif ( $sCode eq '_native_' ) {
             $sCode = 'sjis';
         }
-        return Jcode::convert($sTxt, $oThis->{Code}, $sCode);
+        return Jcode::convert( $sTxt, $oThis->{Code}, $sCode );
     }
     else {
         return $sTxt;
     }
 }
+
 #------------------------------------------------------------------------------
 # FmtStringDef (for Spreadsheet::ParseExcel::FmtJapan)
 #------------------------------------------------------------------------------
 sub FmtStringDef {
-    my($oThis, $iFmtIdx, $oBook) =@_;
-    return $oThis->SUPER::FmtStringDef($iFmtIdx, $oBook, \%hFmtJapan);
+    my ( $oThis, $iFmtIdx, $oBook ) = @_;
+    return $oThis->SUPER::FmtStringDef( $iFmtIdx, $oBook, \%hFmtJapan );
 }
+
 #------------------------------------------------------------------------------
 # ValFmt (for Spreadsheet::ParseExcel::FmtJapan)
 #------------------------------------------------------------------------------
 sub ValFmt {
-    my($oThis, $oCell, $oBook) =@_;
-    return $oThis->SUPER::ValFmt($oCell, $oBook);
+    my ( $oThis, $oCell, $oBook ) = @_;
+    return $oThis->SUPER::ValFmt( $oCell, $oBook );
 }
+
 #------------------------------------------------------------------------------
 # ChkType (for Spreadsheet::ParseExcel::FmtJapan)
 #------------------------------------------------------------------------------
 sub ChkType {
-    my($oPkg, $iNumeric, $iFmtIdx) =@_;
-# Is there something special for Japan?
-    return $oPkg->SUPER::ChkType($iNumeric, $iFmtIdx);
+    my ( $oPkg, $iNumeric, $iFmtIdx ) = @_;
+
+    # Is there something special for Japan?
+    return $oPkg->SUPER::ChkType( $iNumeric, $iFmtIdx );
 }
+
 #------------------------------------------------------------------------------
 # CnvNengo (for Spreadsheet::ParseExcel::FmtJapan)
 #------------------------------------------------------------------------------
 sub CnvNengo {
-    my($iKind, @aTime) = @_;
-    my $iWk = sprintf('%04d%02d%02d', $aTime[5], $aTime[4], $aTime[3]);
-    if($iWk    lt '19120730') {
+    my ( $iKind, @aTime ) = @_;
+    my $iWk = sprintf( '%04d%02d%02d', $aTime[5], $aTime[4], $aTime[3] );
+    if ( $iWk lt '19120730' ) {
         my $iY = $aTime[5] - 1867;
-        return ($iKind == 1)? "M$iY" : 
-                Jcode::convert("$iY", $_Code, 'euc');
+        return ( $iKind == 1 )
+          ? "M$iY"
+          : Jcode::convert( "$iY", $_Code, 'euc' );
     }
-    elsif($iWk lt '19261225') {
+    elsif ( $iWk lt '19261225' ) {
         my $iY = $aTime[5] - 1911;
-        return ($iKind == 1)? "T$iY" : 
-                Jcode::convert("$iY", $_Code, 'euc');
+        return ( $iKind == 1 )
+          ? "T$iY"
+          : Jcode::convert( "$iY", $_Code, 'euc' );
     }
-    elsif($iWk lt '19890108' ) {
+    elsif ( $iWk lt '19890108' ) {
         my $iY = $aTime[5] - 1925;
-        return ($iKind == 1)? "S$iY" : 
-                Jcode::convert("$iY", $_Code, 'euc');
+        return ( $iKind == 1 )
+          ? "S$iY"
+          : Jcode::convert( "$iY", $_Code, 'euc' );
     }
     else {
         my $iY = $aTime[5] - 1988;
-        return ($iKind == 1)? "H$iY" :
-                Jcode::convert("ʿ$iY", $_Code, 'euc');
+        return ( $iKind == 1 )
+          ? "H$iY"
+          : Jcode::convert( "ʿ$iY", $_Code, 'euc' );
     }
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Spreadsheet::ParseExcel::FmtJapan - A class for Cell formats.
+
+=head1 SYNOPSIS
+
+See the documentation for Spreadsheet::ParseExcel.
+
+=head1 DESCRIPTION
+
+This module is used in conjunction with Spreadsheet::ParseExcel. See the documentation for Spreadsheet::ParseExcel.
+
+=head1 AUTHOR
+
+Maintainer 0.40+: John McNamara jmcnamara@cpan.org
+
+Maintainer 0.27-0.33: Gabor Szabo szabgab@cpan.org
+
+Original author: Kawai Takanori kwitknr@cpan.org
+
+=head1 COPYRIGHT
+
+Copyright (c) 2009 John McNamara
+
+Copyright (c) 2006-2008 Gabor Szabo
+
+Copyright (c) 2000-2006 Kawai Takanori
+
+All rights reserved.
+
+You may distribute under the terms of either the GNU General Public License or the Artistic License, as specified in the Perl README file.
+
+=cut
